package ch.zhaw.gartenverwaltung;

import ch.zhaw.gartenverwaltung.bootstrap.AppLoader;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.Button;
import javafx.scene.layout.AnchorPane;
import javafx.scene.layout.Pane;

import java.io.IOException;
import java.net.URL;
import java.util.ResourceBundle;
import java.util.logging.Level;
import java.util.logging.Logger;

public class MainFXMLController implements Initializable {
    private static final Logger LOG = Logger.getLogger(MainFXMLController.class.getName());
    private final AppLoader appLoader = new AppLoader(this);
    @FXML
    private Button home_button;

    @FXML
    private AnchorPane mainPane;

    @FXML
    private Button myGarden_button;

    @FXML
    private Button mySchedule_button;

    @FXML
    private Button plants_button;

    public MainFXMLController() throws IOException {
    }

    @FXML
    void goToHome() throws IOException {
        showPaneAsMainView("Home.fxml");
        styleChangeButton(home_button);
    }

    @FXML
    void goToMyPlants() throws IOException {
        showPaneAsMainView("MyGarden.fxml");
        styleChangeButton(myGarden_button);
    }

    @FXML
    void goToMySchedule() throws IOException {
        showPaneAsMainView("MySchedule.fxml");
        styleChangeButton(mySchedule_button);
    }

    @FXML
    void goToPlants() throws IOException {
        showPaneAsMainView("Plants.fxml");
        styleChangeButton(plants_button);
    }

    /**
     * Updates the mainPane with the selected fxml file.
     * set HGrow and VGrow to parent AnchorPane.
     * Sends MainController to other Controllers.
     * @param fxmlFile string of fxml file
     * @throws IOException exception when file does not exist
     */
    public void showPaneAsMainView(String fxmlFile) throws IOException {
        Pane anchorPane = appLoader.loadPane(fxmlFile);
        mainPane.getChildren().setAll(anchorPane);
        anchorPane.prefWidthProperty().bind(mainPane.widthProperty());
        anchorPane.prefHeightProperty().bind(mainPane.heightProperty());
    }


    private void preloadPanes() throws IOException {
        appLoader.loadAndCacheFxml("MyGarden.fxml");
        appLoader.loadAndCacheFxml("MySchedule.fxml");
        appLoader.loadAndCacheFxml("Plants.fxml");
    }

    private void styleChangeButton(Button button) {
        //ToDo changeStyle of the menu buttons
    }

    /**
     * loads the default FXML File
     * {@inheritDoc}
     */
    @Override
    public void initialize(URL url, ResourceBundle resourceBundle) {
        try {
            preloadPanes();
            showPaneAsMainView("Home.fxml");
            styleChangeButton(home_button);
        } catch (IOException e) {
            LOG.log(Level.SEVERE, "Failed to load FXML-Pane!", e);
        }
    }
}

